#ifndef NT2_INCLUDE_FUNCTIONS_LINSOLVE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LINSOLVE_HPP_INCLUDED

#include <nt2/linalg/include/functions/linsolve.hpp>

#endif
